@@ -7,7 +7,7 @@ Attean::API::Store - Triple/quad store role
 
 =head1 VERSION
 
-This document describes Attean::Store version 0.002_01
+This document describes Attean::Store version 0.002_02
 
 =head1 DESCRIPTION
 
@@ -55,6 +55,11 @@ package Attean::API::TripleStore 0.001 {
 		return $count;
 	}
 	
+	sub count_triples_estimate {
+		my $self	= shift;
+		return $self->count_triples(@_);
+	}
+	
 	sub size {
 		my $self	= shift;
 		return $self->count_triples();
@@ -80,7 +85,7 @@ package Attean::API::TimeCacheableTripleStore 0.001 {
 	use Moo::Role;
 	with 'Attean::API::TripleStore';
 	
-	requires 'metime_for_triples';
+	requires 'mtime_for_triples';
 }
 
 package Attean::API::QuadStore 0.001 {
@@ -99,6 +104,11 @@ package Attean::API::QuadStore 0.001 {
 		return $count;
 	}
 	
+	sub count_quads_estimate {
+		my $self	= shift;
+		return $self->count_quads(@_);
+	}
+	
 	sub get_graphs {
 		my $self	= shift;
 		my $iter	= $self->get_quads(@_);
